@@ -267,7 +267,7 @@ impl GeneralReadout for LinuxGeneralReadout {
         Ok(content.name)
     }
 
-    fn local_ip(&self, interface: String) -> Result<String, ReadoutError> {
+    fn local_ip(&self, interface: Option<String>) -> Result<String, ReadoutError> {
         crate::shared::local_ip(interface)
     }
 
