@@ -413,7 +413,7 @@ pub trait GeneralReadout {
     /// specified interface.
     ///
     /// _e.g._ `192.168.1.11`
-    fn local_ip(&self, interface: String) -> Result<String, ReadoutError> {
+    fn local_ip(&self, interface: Option<String>) -> Result<String, ReadoutError> {
         Err(STANDARD_NO_IMPL.clone())
     }
 
